(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    248488,       4451]
NotebookOptionsPosition[    244993,       4327]
NotebookOutlinePosition[    245889,       4360]
CellTagsIndexPosition[    245716,       4353]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.456486753323069*^9, 3.4564867611682034`*^9}, {
  3.5734764300066023`*^9, 3.573476433997271*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 2.6.0 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.573476442935688*^9, 3.573477284430644*^9, 
  3.573477457121531*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.456486764078146*^9, 3.456486768296845*^9}, 
   3.486707724812611*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \[NoBreak]\\!\\({\\({1, \
1\\/2}\\)}\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5734772871383257`*^9, 3.573477459484151*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(ZeemanBasis[\\(\\(\\(\\({\\({1, 1\\/2}\\)}\\)\\), \
\\(\\(BasisLabels \[Rule] Automatic\\)\\)\\)\\)]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.5734772871383257`*^9, 3.5734774595400257`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["define a relaxation superoperator", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}}],

Cell["\<\
in this case the relaxation model corresponds to isotropic random fields, in \
the extreme narrowing limit\
\>", "Text",
 CellChangeTimes->{{3.486711829070991*^9, 3.48671184950311*^9}, {
  3.573477119467581*^9, 3.5734771252360373`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"T1inv", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.486711855605392*^9, 3.4867118637203217`*^9}, 
   3.486711963993827*^9, {3.486712383145681*^9, 3.4867123833761044`*^9}, {
   3.486712473392042*^9, 3.4867125024664993`*^9}, {3.5734769708847322`*^9, 
   3.573476972612607*^9}, 3.573477060908832*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RelaxationSuperoperator", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"T1inv", "/", "2"}], ")"}]}], " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", "m"}], " ", 
       RowBox[{"DoubleCommutationSuperoperator", "[", 
        RowBox[{
         RowBox[{"opT", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "m"}], "}"}]}], "]"}], ",", 
         RowBox[{"opT", "[", 
          RowBox[{"1", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "m"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4867118667593412`*^9, 3.486711926741947*^9}, 
   3.5734769772788963`*^9, {3.5734770218038473`*^9, 3.573477024249441*^9}}],

Cell["\<\
The matrix representation of the relaxation superoperator has the relaxation \
rate constants on the diagonal\
\>", "Text",
 CellChangeTimes->{{3.573477091571488*^9, 3.573477108803009*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SuperoperatorMatrixRepresentation", "[", 
   RowBox[{"RelaxationSuperoperator", ",", 
    RowBox[{"CartesianProductOperatorBasis", "[", "]"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5734769845783463`*^9, 3.573477005632082*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "2"}], "0", "0"},
     {"0", "0", 
      RowBox[{"-", "2"}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", "2"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 0, 2, 4, 5}, {{2}, {3}, {3}, {2}, {4}}}, {-2, 0, -2, 
      0, -2}}]]]]], "Output",
 CellChangeTimes->{{3.5734770007523003`*^9, 3.57347703000229*^9}, 
   3.573477063337139*^9, 3.5734772873993692`*^9, 3.573477459712634*^9}]
}, Open  ]],

Cell["\<\
In this case T1 and T2 are the same, and are both equal to 1/2 second.\
\>", "Text",
 CellChangeTimes->{{3.573477112876412*^9, 3.5734771330761757`*^9}, {
  3.5734774643378887`*^9, 3.57347746956896*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["define the Hamiltonian to use for thermalization", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718471310871*^9, 3.4867184833813047`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]0", "=", 
   RowBox[{
    RowBox[{"-", "500"}], " ", 
    RowBox[{"10", "^", "6"}], " ", "2", "\[Pi]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.486718488293942*^9, 3.486718507640718*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H0", "=", 
  RowBox[{"\[Omega]0", " ", 
   RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.486718485652246*^9, 3.486718518038591*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1000000000"}], " ", "\[Pi]", " ", 
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "z"}]],
   DisplayForm]}]], "Output",
 CellChangeTimes->{
  3.486718518660253*^9, 3.4867187068018723`*^9, 3.486718772144965*^9, 
   3.4867191501368504`*^9, 3.486719510083908*^9, 3.486721636681342*^9, 
   3.48672289796165*^9, 3.486723930056284*^9, 3.486723998651869*^9, 
   3.48673833304524*^9, 3.486738370995159*^9, 3.4867453848537693`*^9, 
   3.486779611672029*^9, 3.497512062130046*^9, 3.497574432561708*^9, 
   3.4976483379622993`*^9, 3.5020118563699703`*^9, 3.5020121159354153`*^9, 
   3.502712070927772*^9, 3.503307170331428*^9, {3.510318882896899*^9, 
   3.510318899537768*^9}, 3.5103189378619747`*^9, 3.5131624250829372`*^9, 
   3.533177871482752*^9, 3.5331780251963673`*^9, 3.573476463881515*^9, 
   3.573476522509369*^9, 3.573477139588119*^9, 3.573477287475349*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["define the thermalized relaxation superoperator", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ThermalizeSuperoperator"}]], "Input",
 CellChangeTimes->{3.4867185447916527`*^9}],

Cell[BoxData[
 StyleBox["\<\"ThermalizeSuperoperator[sop,Hamiltonian,Temperature] corrects \
the eigenoperators of a superoperator so that a Boltzmann population \
distribution under the Hamiltonian Hamiltonian is established at long \
evolution times.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.573477287658451*^9},
 CellTags->"Info3573477287-1274295"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ThermalizedRelaxationSuperoperator", "=", "\[IndentingNewLine]", 
   RowBox[{"ThermalizeSuperoperator", "[", "\[IndentingNewLine]", 
    RowBox[{
    "RelaxationSuperoperator", ",", "\[IndentingNewLine]", "H0", ",", 
     "\[IndentingNewLine]", "300"}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4867118667593412`*^9, 3.486711926741947*^9}, {
   3.486718527891418*^9, 3.48671856801668*^9}, {3.486718808024767*^9, 
   3.486718830074431*^9}, 3.486721653894927*^9, 3.486738392547227*^9, {
   3.573477150826331*^9, 3.5734771511277933`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetOperatorBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the operator basis has been set to \
\[NoBreak]\\!\\(ShiftAndZOperatorBasis[\\(\\(\\(\\({\\({1, 1\\/2}\\)}\\)\\), \
\\(\\(Sorted \[Rule] CoherenceOrder\\)\\)\\)\\)]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.573477287929194*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
define the thermal equilbrium density operator, and the thermal equilibrium \
magnetization\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}, {
  3.4867188411580563`*^9, 3.4867188496926317`*^9}, {3.48671888920588*^9, 
  3.4867188976605263`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ThermalEquilibriumDensityOperator"}]], "Input",
 CellChangeTimes->{3.486718861174774*^9}],

Cell[BoxData[
 StyleBox["\<\"ThermalEquilibriumDensityOperator[Hamiltonian, Temperature] \
sets up a thermal equilibrium density operator under the specified \
Hamiltonian at the specified temperature.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5734772924774303`*^9},
 CellTags->"Info3573477292-1274295"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]eq", "=", 
  RowBox[{"ThermalEquilibriumDensityOperator", "[", 
   RowBox[{"H0", ",", "300"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4867188684986258`*^9, 3.486718880943441*^9}, {
  3.5734771608264008`*^9, 3.5734771611601343`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"Operator", "["}], 
   TagBox[
    RowBox[{"SparseArray", "[", 
     RowBox[{
      InterpretationBox[
       RowBox[{"\<\"<\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\">\"\>"}],
       SequenceForm["<", 2, ">"],
       Editable->False], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}]}], "]"}],
    False,
    Editable->
     False], "\<\",<<..>>, OperatorType\[Rule]\"\>", "\<\"\\\"Hermitian\\\"\"\
\>", "\<\"]\"\>"}],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.486718881990088*^9, 3.486719511002288*^9, 3.48672019730903*^9, 
   3.4867216382050943`*^9, 3.486722899083391*^9, 3.486723931184443*^9, 
   3.486723999690855*^9, 3.486724083665607*^9, 3.486738334064212*^9, 
   3.4867383718690233`*^9, 3.4867453857439957`*^9, 3.486779612483968*^9, 
   3.4975120749717693`*^9, 3.497574433350011*^9, 3.497648338767009*^9, 
   3.5020118659963427`*^9, 3.502012116752816*^9, 3.502712072168433*^9, 
   3.5033071713224573`*^9, {3.510318883817801*^9, 3.5103189003263903`*^9}, 
   3.510318948049429*^9, 3.513162426032153*^9, 3.533177872340411*^9, 
   3.5331780261763487`*^9, 3.573476464713188*^9, 3.573476523296983*^9, 
   3.57347716432482*^9, 3.573477292655004*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
define the nutation frequency for a weak rf pulse and an inversion recovery \
sequence\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}, {
  3.4867188411580563`*^9, 3.4867188496926317`*^9}, {3.48671888920588*^9, 
  3.4867188976605263`*^9}, {3.573477199570359*^9, 3.5734772188258657`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Omega]nut", "=", 
   RowBox[{"2", "\[Pi]", " ", "10"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]360", "=", 
   RowBox[{"2", 
    RowBox[{"\[Pi]", "/", "\[Omega]nut"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"sequence", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"10", " ", 
       RowBox[{"10", "^", 
        RowBox[{"-", "3"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Omega]nut", " ", 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", 
      RowBox[{"\[Tau]360", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"None", ",", "2"}], "}"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.486710250475978*^9, 3.486710283729823*^9}, {
   3.486712007923459*^9, 3.4867120114968653`*^9}, {3.486712049546351*^9, 
   3.4867120557928553`*^9}, 3.4867121079698143`*^9, {3.4867122255640497`*^9, 
   3.486712228360004*^9}, {3.4867124354172163`*^9, 3.486712467201076*^9}, {
   3.573476487371501*^9, 3.5734765023554*^9}, {3.573476558166705*^9, 
   3.573476562545412*^9}, {3.57347663249076*^9, 3.573476680446766*^9}, 
   3.573476895473652*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"None", ",", 
     FractionBox["1", "100"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"20", " ", "\[Pi]", " ", 
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "x"}]],
       DisplayForm]}], ",", 
     FractionBox["1", "20"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"None", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5734765638766203`*^9, {3.573476673404855*^9, 3.5734766835020723`*^9}, 
   3.573476904722275*^9, 3.5734772250439672`*^9, 3.573477296603079*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
define the resonance offset and the offset Hamiltonian\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}, {
  3.4867188411580563`*^9, 3.4867188496926317`*^9}, {3.48671888920588*^9, 
  3.4867188976605263`*^9}, {3.573477199570359*^9, 3.573477242378765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]off", "=", 
   RowBox[{"2", "\[Pi]", " ", "5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.573476850343155*^9, 3.5734768572782717`*^9}, {
  3.573476899984638*^9, 3.573476901375948*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hoff", "=", 
   RowBox[{"\[Omega]off", " ", 
    RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.573477245284848*^9, 3.573477251279499*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
calculate the equilibrium magnetization (needed for normalization)\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}, {
  3.4867188411580563`*^9, 3.4867188496926317`*^9}, {3.48671888920588*^9, 
  3.4867188976605263`*^9}, {3.573477199570359*^9, 3.573477269700633*^9}, {
  3.5734773603104687`*^9, 3.573477369915004*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M0", "=", 
   RowBox[{"OperatorAmplitude", "[", 
    RowBox[{"\[Rho]eq", "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"M0", "//", "EngineeringForm"}]}], "Input",
 CellChangeTimes->{{3.486719268789762*^9, 3.486719278926063*^9}, {
   3.486738405857522*^9, 3.486738406745163*^9}, {3.497512095378702*^9, 
   3.4975121011939173`*^9}, {3.502011901219558*^9, 3.502011941187924*^9}, 
   3.5027120839338293`*^9, 3.53317797328157*^9, {3.5734765788180513`*^9, 
   3.5734765845656013`*^9}}],

Cell[BoxData[
 TagBox[
  InterpretationBox[
   RowBox[{"\<\"39.9936\"\>", "\[Times]", 
    SuperscriptBox["10", "\<\"-6\"\>"]}],
   0.000039993644541214124`,
   AutoDelete->True],
  EngineeringForm]], "Output",
 CellChangeTimes->{
  3.486719280905628*^9, 3.4867193751447773`*^9, 3.48671951127206*^9, {
   3.486720184922586*^9, 3.486720199971418*^9}, 3.48672163855844*^9, 
   3.486722899283901*^9, 3.486723931822798*^9, 3.486723999891474*^9, 
   3.486724087036304*^9, 3.486738334598448*^9, 3.486738372250408*^9, {
   3.4867384074743443`*^9, 3.486738416247563*^9}, 3.486745386226738*^9, 
   3.486779612700857*^9, {3.497512091275128*^9, 3.497512102072547*^9}, 
   3.4975744335521927`*^9, 3.497574471995729*^9, 3.497648338984322*^9, 
   3.502011871877349*^9, {3.50201190741826*^9, 3.502011941969306*^9}, 
   3.502012117103079*^9, 3.502012168802524*^9, {3.502712072808625*^9, 
   3.502712084539877*^9}, 3.5033071715736523`*^9, {3.5103188840839863`*^9, 
   3.5103189005442667`*^9}, 3.510318962132423*^9, 3.513162426322209*^9, 
   3.5331778726098967`*^9, 3.53317791360905*^9, 3.533178026612856*^9, 
   3.573476465091919*^9, 3.5734765235968246`*^9, 3.573476585486026*^9, {
   3.573476673538951*^9, 3.573476683592368*^9}, 3.573476904839284*^9, 
   3.573477296813693*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
calculate the magnetization trajectories, in the presence of simultaneous \
resonance offset and relaxation\
\>", "Subsection",
 CellChangeTimes->{{3.486707851553718*^9, 3.486707854296624*^9}, {
  3.486710290680942*^9, 3.486710315247572*^9}, {3.486711822168579*^9, 
  3.486711826326964*^9}, {3.486718522102881*^9, 3.486718524413445*^9}, {
  3.4867188411580563`*^9, 3.4867188496926317`*^9}, {3.48671888920588*^9, 
  3.4867188976605263`*^9}, {3.573477199570359*^9, 3.573477269700633*^9}, {
  3.5734773603104687`*^9, 3.573477392932157*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "CombineEvolutionGenerators"}]], "Input",
 CellChangeTimes->{{3.573477396292232*^9, 3.573477400761773*^9}}],

Cell[BoxData[
 StyleBox["\<\"CombineEvolutionGenerators[a, b, ..] combines Hamiltonians, \
Liouvillians, time-dependent Hamiltonian functions, and so on, to generate a \
single evolution generator.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5734774152022867`*^9},
 CellTags->"Info3573477415-1274295"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"Ixtraj", ",", "Iytraj", ",", "Iztraj"}], "}"}], "=", 
  "\[IndentingNewLine]", 
  RowBox[{"Trajectory", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Rho]eq", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<y\>\"", "]"}], ",", 
       RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "sequence", ",", "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", 
     RowBox[{"CombineEvolutionGenerators", "[", 
      RowBox[{"ThermalizedRelaxationSuperoperator", ",", "Hoff"}], "]"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"NormalizationFactor", "\[Rule]", "M0"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.4565095226613693`*^9, 3.456509562395952*^9}, {
   3.486708014261339*^9, 3.48670803633846*^9}, {3.4867103439558783`*^9, 
   3.486710347265813*^9}, {3.486711933970869*^9, 3.4867119418514843`*^9}, 
   3.486712081946656*^9, {3.486718948720776*^9, 3.4867190047926292`*^9}, 
   3.486719037585278*^9, 3.486719256934284*^9, {3.4867193664219418`*^9, 
   3.48671937167612*^9}, 3.497574426033483*^9, 3.497574465914205*^9, 
   3.502012164185834*^9, {3.5103189524009027`*^9, 3.510318958039098*^9}, {
   3.533177887628249*^9, 3.533177908748633*^9}, 3.573476533645791*^9, {
   3.573476595459605*^9, 3.573476601506658*^9}, {3.573476705502075*^9, 
   3.57347672920824*^9}, {3.573476861033819*^9, 3.57347687574571*^9}, 
   3.5734774117900476`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox["\<\"2.06\"\>",
          2.06,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox["\<\"2.06\"\>",
          2.06,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox["\<\"2.06\"\>",
          2.06,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.456509549294127*^9, 3.45650956323951*^9}, 
   3.456509647542842*^9, 3.4565098974113092`*^9, 3.456545656175568*^9, 
   3.456546623398144*^9, {3.456570783390377*^9, 3.456570796273484*^9}, 
   3.456570832703512*^9, 3.458994532296883*^9, 3.459442723512301*^9, 
   3.461066537245344*^9, 3.4613298032665*^9, {3.4620059345073957`*^9, 
   3.4620059394326477`*^9}, 3.4640250841192636`*^9, 3.464803447884685*^9, 
   3.465814125692009*^9, 3.467015925147357*^9, {3.486707964429309*^9, 
   3.4867079728747177`*^9}, 3.4867080041836433`*^9, 3.486708037345064*^9, 
   3.486709666747039*^9, 3.486710349350082*^9, {3.486710507580456*^9, 
   3.486710514165419*^9}, 3.4867116858217497`*^9, 3.48671180174515*^9, {
   3.4867119427788887`*^9, 3.486711969499385*^9}, 3.48671201808499*^9, {
   3.4867120632648287`*^9, 3.486712082443878*^9}, 3.4867121131937323`*^9, 
   3.4867122357661867`*^9, 3.4867123895584383`*^9, {3.4867124510192757`*^9, 
   3.486712508181238*^9}, 3.48671900628371*^9, 3.486719038506874*^9, 
   3.4867192575780277`*^9, 3.486719372266625*^9, 3.486719511170126*^9, {
   3.486720184757659*^9, 3.486720199819623*^9}, 3.486721638465272*^9, 
   3.48672289921564*^9, 3.4867239316446667`*^9, 3.486723999836917*^9, 
   3.4867240869143257`*^9, 3.4867383345289183`*^9, 3.486738372182994*^9, 
   3.486738416129726*^9, 3.486745386177072*^9, 3.48677961264953*^9, 
   3.497512079261281*^9, 3.497574433510717*^9, {3.4975744686296864`*^9, 
   3.49757447188892*^9}, 3.4976483389439507`*^9, 3.5020118717620173`*^9, 
   3.502012117059407*^9, 3.5020121651043863`*^9, 3.502712072685609*^9, 
   3.503307171527993*^9, {3.510318884030615*^9, 3.510318900506124*^9}, 
   3.510318958899253*^9, 3.513162426271318*^9, 3.533177872578972*^9, 
   3.53317791354185*^9, 3.533178026562402*^9, 3.573476465052785*^9, 
   3.5734765235495853`*^9, 3.573476603445766*^9, {3.573476673780134*^9, 
   3.573476683768804*^9}, 3.573476730295336*^9, {3.5734768767302313`*^9, 
   3.5734769050649776`*^9}, 3.5734772971043158`*^9, 3.5734774155139008`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Ixtraj", "[", "t", "]"}], ",", 
     RowBox[{"Iytraj", "[", "t", "]"}], ",", 
     RowBox[{"Iztraj", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "sequence", "]"}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45650956890828*^9, 3.456509571083004*^9}, {
   3.4565099019330606`*^9, 3.4565099070840673`*^9}, {3.456545660832933*^9, 
   3.4565456665182953`*^9}, {3.486708063467409*^9, 3.4867080670420017`*^9}, 
   3.486708120749165*^9, {3.486710361170927*^9, 3.486710379897279*^9}, {
   3.486711948238356*^9, 3.4867119524087543`*^9}, 3.4867120853542433`*^9, {
   3.486719021040556*^9, 3.486719022030527*^9}, {3.4867190812634487`*^9, 
   3.486719087021311*^9}, 3.486719284873708*^9, {3.4867195204455214`*^9, 
   3.486719547099317*^9}, {3.486720213203229*^9, 3.4867202135131397`*^9}, 
   3.486738411780472*^9, 3.497512119941382*^9, 3.510318894553425*^9, {
   3.5734766115938377`*^9, 3.573476612431534*^9}, {3.573476733121146*^9, 
   3.57347674245613*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJw8d3k4Vd8Xd8ZQCakkIflKMhRJKVYkZSYqlcxFppCQIZV5SBLJlHmW4ZrH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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
    LineBox[CompressedData["
1:eJw8W3k0FG64RgqJlCXJliShsgvpLVsREkJSISEhSyGkQkKShOxkD8m+8zH2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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
    LineBox[CompressedData["
1:eJw91ok7lXkbB/BHISmKlHLC0SIHZZmImul+hrRIjYpBTSliLDOUDkYy9qVC
lshWQsiWfW/Or7GU7KGTDofHmnOcLbJkyet9r+vtvq7v9b0+f8H3VrJxPW+3
BsOw+NX8t0dV71RviLE/iv3vBNDnFb1uqfQ6/N/yj+/TBKXU7z4owSWxCa/v
NvE56zUi4fvd+UkrWzS7/L67ZNbC2UU+4LurzhfV5TsEfjfthZjcZGkQsBJk
13as8KFB/NpNykowkMi+xnvm+NBsX930u3EoVNxKj0gd4kNnnRQ5Ky4MGqsC
py4gPtAVnDxHibsgvJey9lIUH/pv17XvUr8P5OWUlB4zPgzT5ZSveYaDd0YT
Y3wjHya0b/mk1kXA2XFdIVoVD7iRLT1MiQcgfKzlarglD7xmpLZFqkfB3CWf
w/c4XLizm/bz/q4oOKNPSZ2hcsH3nNOfrZ7RMB0TYiI9xYEA322JzvIxMOR7
MZRynQPBBXUN4vUxEOA5P3W3ZRLC+lwEOQ6x0FavYh+qMgmRh96cmCh9CNvo
MXn/NrAg2u7WrVCrOJhf2hdCE2bBw1jFVOWVOIg3JEv3HpmAJL7n7HXjR3Bm
o562VPQ4ZGWrZA4RiTAPvupHR4ch531Pp19IEnhOB7dmsIYgf63/kqJ6MgSs
t6glWASUWH+8cMUzBWjFVoPj1Uz4R/bemj6JVLgmYhJVr/ceXhnpHrhdmgrO
63r25kl2w5D+5/xw9acwk7qmhz7cCaO/P+5V63oKZyN8pWgyb4FdP6PhJJ8O
WqNjjYLMQuAwWhr1b6SD9/a5X9vKHgP3c9ql9fXpwK38ccNSqjMSKJ4Nfe6Q
AStOY2lmksVo1jtrYLz0GbR91Q+zqn2DrlUaZhVIZMLbTr9AQWwLap0i/qT+
nglr0mDZ2LgDZTiSloVIWfDIoU94cXc3ksysamiiZgFWox2c19iDbhPm4Q/a
s8DaLd7kl/N0ZGoRRZIPyAbHBx4ZEpSPqDZm/8hIXzaYx27blHiTgZTbm3Nz
dZ7DVJ7shYW0PhSz3sHt5oPn0G9nvCOyuh8tHxM5rMd6DkyhowdeVTKRg1+6
0IpBDoidcG7fkDKAemrhbWNKDsx8FGYv2g0imOuPCp/NgVpaZmGcOIFytW9b
XjDNhVnVzLh0MwJtdZEly+XmglWw28k10QTyyyn7RKzNA7mKLclJiECc0XOF
2ZfzYOOG8WQrgkAWZL6HS2UeNOTdTtSZJlDdpfCjOlL5QKeF79o/T6ADjyii
S075QC2TETrBJ1Bi1+u2uoZ8MJLw1YzpJZCw5PW4uwoF8KJzU8feMgK5nhK6
bPpXAWjU/i2uFEAgRtCTPbJdBaD5lbEuz4BAx18d4TDVXsCfYlERY5ODqHix
t/RZ8As4yPgFu6I3iHYe8vB2HnwBhe92ux6qHkBhblsMtfUL4c2UlqlIwgCa
LigS/xpTCJYUx+4BjwF0hXWmC3EKIaO+/Eu9+QC6HjNjYri7CKp8RIrKDg4g
Oc2GImXTIuj1OyFUvGUAhThf+4ubUwStyvbmre+Y6Lfh5HXel4sha6TyfMRZ
JlrfuVk5vqEEgmTSSDrG/cg2b8GmNaYc8vw6VlZOMdCC4qxBxctycDBooFDV
GSjq4eddT8fLoeYO+9tnSQZ66TMxfOtwBai773ki3vMRyZjSbUjDFUCRmbco
vPIRvf5SbOOkVQXL0q1f6917kepRRxuxzhowMz6iJZxHR14Tk5rpoq+gN+3p
Qx2tbuS/96eJSEojdB/S+Dcw4i3am4O95NU2Q9mxSPO1ftWIKWa9VYHfAfZX
A+47GYajxA+PjIimLugRPtUbZ1ECI743+9dHvAeroIcu69bWw6H47brJSr3A
yo1LDKG2wMeOeflxLgN6d9A3vOa/gyDPrKaEe0wIN2+t3Bn+HlRq0j9JSRDg
fM9Ab7yjF3SbJbXLbgxB/HAdXVO6H05GD12+93IYjue2o1nmAAixO01/2jMK
1RoskbBuAoy5VTd/Cx4Dv2Fdkq3MMCRkr6MWto/DqUu/jhXtG4GIabefBn+Y
AP6hCMHpw6MQMntswsCfBeSSXFNi7xjsu//DxUA2G1pm4wT2m8fBolluQeMM
B+ad08VsR8Yh/JWD9+YELoyd8Cc5JHwCx5Pd9W3feNC+9djh9yYTkGnY5TGo
LIA33R6myZ8m4Ipe5S7JFgFkd9NK7t5iwaS7qraaz2eo80+m7V9hwYLkOW2b
3VPgckRQuODBBqZAJD70wxQsPWuwN+GxQUylcrNt2DSExY3J5lhNQnkN6Y7l
/i+wc+u/em/KJ0E3XvL0j8QXgHgGPV2KA/ptZeKHQ2fAoidqxvUqB4KsLIa4
qrOQX1VaU5zNgYwDYaSo/lmYFJmSofM4cMz6j+MmAXMgz5GgDqpxobp3oGdW
Zx7SP9DVih24UFQgbFbLnIfnVBKzP4UL/A/KbJ2Ar7D015Wboq1cWHP6w8iT
gwtgzbIL2bLIhUc7jrQr9S3AU4XkuRu7eYBp7d8Z+2ARyEWpi2mneVD8mORf
gy/BNk4rs9mVB6N2/9AXx5bgs4a52rtIHkx6cB+oJS5DembRO1oBD6gjnfru
+DdwOLmZON7EA6PMogXq6DcwMrJeMSR4wC5UULSNX4HBxgp3nXkeiG0gJ+ko
YDju/oz8anUPdxWjk88VMbyks1FhuwQffrSwnpNTwvBPSdLLrqu+kfHEDNuD
4aIhv11UlORD7xH5TS0UDD8hO51wZxMfcv6QC7qqg+Gvo1Q0taT5YNwu43Lf
BMM1XzZtDZTlw3Vq2c5vZzD8ZyULjQ+r/lvOrOXGLxhOUL1U1bbzocQ+VuXX
8xheO5HZ2LVq0orUCNkSw03U3kWR5fjA0dhkWWGL4c42y4EVO/kgSn8hSrHD
8EtJ7FoxeT6Q75wtT7bHcMrCDvrFVZs1RUj7O2K4ra5T8bdVv7y6se20K4ZH
sZeEjRRX/wXRfG/aDQyXfb3PNH7VgvzTqlpuGP7Ihe3zadV7vt4L3eaO4SmF
1/zvkvlwNFVV964Hhm8JVLNgrNrSqHl00RPD7RMrN6kp8cFt0jHWxQvDPUI2
53mvOiJ6vcHQbQw/x8Aprav+D6losqg=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->None,
  AxesOrigin->{0, 0},
  Frame->True,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.456509572000661*^9, 3.456509653636228*^9, 3.456509899944787*^9, {
   3.456545656336225*^9, 3.456545667486722*^9}, 3.4565466234500847`*^9, 
   3.456570783589847*^9, 3.456570837050729*^9, 3.458994532350522*^9, 
   3.459442723564172*^9, 3.4610665372926807`*^9, 3.4613298034579077`*^9, 
   3.46200594275671*^9, 3.464025084171768*^9, 3.464803447935872*^9, 
   3.465814125726612*^9, 3.467015925309105*^9, {3.486708059353109*^9, 
   3.486708068097351*^9}, 3.486708121976638*^9, 3.486709666822544*^9, {
   3.48671036630529*^9, 3.4867103804881687`*^9}, {3.486710507722886*^9, 
   3.48671051763118*^9}, 3.4867116859249*^9, 3.486711801801916*^9, {
   3.486711945143607*^9, 3.48671196963496*^9}, 3.486712018241723*^9, {
   3.486712063393299*^9, 3.486712113250649*^9}, 3.486712235883725*^9, 
   3.486712389695526*^9, {3.4867124511365643`*^9, 3.486712508310315*^9}, {
   3.486719013038617*^9, 3.486719040748336*^9}, {3.486719082117216*^9, 
   3.48671908760071*^9}, 3.4867192856290007`*^9, 3.486719377022065*^9, {
   3.4867195113542423`*^9, 3.4867195476197853`*^9}, {3.486720184965589*^9, 
   3.486720214053273*^9}, 3.48672163880466*^9, 3.486722899367736*^9, 
   3.486723932168223*^9, 3.486723999960166*^9, 3.486724087087247*^9, 
   3.48673833475369*^9, 3.486738372302227*^9, 3.486738416304305*^9, 
   3.4867453862946167`*^9, 3.486779612767436*^9, 3.497512120657772*^9, 
   3.497574433635701*^9, 3.497574472023785*^9, 3.4976483390680513`*^9, 
   3.502011871926125*^9, 3.502012117206283*^9, 3.502012171079376*^9, 
   3.502712072853722*^9, 3.503307171678586*^9, {3.5103188842209387`*^9, 
   3.510318900644288*^9}, 3.510318967617037*^9, 3.5131624264229403`*^9, 
   3.533177872659319*^9, 3.533177913663018*^9, 3.533178026656052*^9, 
   3.5734764651657953`*^9, 3.573476523639306*^9, 3.573476613019628*^9, {
   3.573476673823957*^9, 3.5734766838131742`*^9}, 3.5734767431457453`*^9, {
   3.5734768794510517`*^9, 3.573476905257291*^9}, 3.573477297335018*^9, 
   3.573477415704988*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SphereAndAxes", "[", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Ixtraj", "[", "t", "]"}], ",", 
         RowBox[{"Iytraj", "[", "t", "]"}], ",", 
         RowBox[{"Iztraj", "[", "t", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"Duration", "[", "sequence", "]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.573476749413145*^9, 3.573476819765298*^9}}],

Cell[BoxData[
 Graphics3DBox[{
   {Opacity[0.1], EdgeForm[None], 
    Polygon3DBox[
     NCache[{{0, 1, 0}, {
       0, Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {0, 0, 1}, {
       0, -Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi]}, {
       0, 
        Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       0, -Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi]}, {
       0, -Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       0, -Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi]}, {0, -1, 0}, {
       0, -Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {
       0, -Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, -Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, -Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, -Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, -Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, -Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, -Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, -Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, -Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, -Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2],
         Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, -Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, -Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, -Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, -Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       0, -Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, -Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, -Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, -Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       0, Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi]}, {
       0, Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi]}, {
       0, Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi]}, {
       0, Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi]}, {
       0, Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi]}, {
       0, Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi]}, {
       0, Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi]}, {
       0, Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi]}, {
       0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       0, Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi]}, {
       0, Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi]}, {
       0, Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi]}, {
       0, Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi]}, {
       0, Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2]}, {
       0, Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi]}, {
       0, Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi]}, {
       0, Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi]}, {
       0, Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi]}, {
       0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       0, Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi]}, {
       0, Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi]}, {
       0, Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi]}, {
       0, Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi]}, {0, 1, 0}}, {{0,
        1, 0}, {0, 0.9980267284282716, 0.06279051952931337}, {
       0, 0.9921147013144779, 0.12533323356430426`}, {
       0, 0.9822872507286887, 0.1873813145857246}, {
       0, 0.9685831611286311, 0.2486898871648548}, {
       0, 0.9510565162951535, 0.30901699437494745`}, {
       0, 0.9297764858882515, 0.3681245526846779}, {
       0, 0.9048270524660195, 0.4257792915650727}, {
       0, 0.8763066800438636, 0.4817536741017153}, {
       0, 0.8443279255020151, 0.5358267949789967}, {
       0, 0.8090169943749475, 0.5877852522924731}, {
       0, 0.7705132427757893, 0.6374239897486896}, {
       0, 0.7289686274214116, 0.6845471059286886}, {
       0, 0.6845471059286886, 0.7289686274214116}, {
       0, 0.6374239897486896, 0.7705132427757893}, {
       0, 0.5877852522924731, 0.8090169943749475}, {
       0, 0.5358267949789967, 0.8443279255020151}, {
       0, 0.4817536741017153, 0.8763066800438636}, {
       0, 0.4257792915650727, 0.9048270524660195}, {
       0, 0.3681245526846779, 0.9297764858882515}, {
       0, 0.30901699437494745`, 0.9510565162951535}, {
       0, 0.2486898871648548, 0.9685831611286311}, {
       0, 0.1873813145857246, 0.9822872507286887}, {
       0, 0.12533323356430426`, 0.9921147013144779}, {
       0, 0.06279051952931337, 0.9980267284282716}, {0, 0, 1}, {
       0, -0.06279051952931337, 0.9980267284282716}, {
       0, -0.12533323356430426`, 0.9921147013144779}, {
       0, -0.1873813145857246, 0.9822872507286887}, {
       0, -0.2486898871648548, 0.9685831611286311}, {
       0, -0.30901699437494745`, 0.9510565162951535}, {
       0, -0.3681245526846779, 0.9297764858882515}, {
       0, -0.4257792915650727, 0.9048270524660195}, {
       0, -0.4817536741017153, 0.8763066800438636}, {
       0, -0.5358267949789967, 0.8443279255020151}, {
       0, -0.5877852522924731, 0.8090169943749475}, {
       0, -0.6374239897486896, 0.7705132427757893}, {
       0, -0.6845471059286886, 0.7289686274214116}, {
       0, -0.7289686274214116, 0.6845471059286886}, {
       0, -0.7705132427757893, 0.6374239897486896}, {
       0, -0.8090169943749475, 0.5877852522924731}, {
       0, -0.8443279255020151, 0.5358267949789967}, {
       0, -0.8763066800438636, 0.4817536741017153}, {
       0, -0.9048270524660195, 0.4257792915650727}, {
       0, -0.9297764858882515, 0.3681245526846779}, {
       0, -0.9510565162951535, 0.30901699437494745`}, {
       0, -0.9685831611286311, 0.2486898871648548}, {
       0, -0.9822872507286887, 0.1873813145857246}, {
       0, -0.9921147013144779, 0.12533323356430426`}, {
       0, -0.9980267284282716, 0.06279051952931337}, {0, -1, 0}, {
       0, -0.9980267284282716, -0.06279051952931337}, {
       0, -0.9921147013144779, -0.12533323356430426`}, {
       0, -0.9822872507286887, -0.1873813145857246}, {
       0, -0.9685831611286311, -0.2486898871648548}, {
       0, -0.9510565162951535, -0.30901699437494745`}, {
       0, -0.9297764858882515, -0.3681245526846779}, {
       0, -0.9048270524660195, -0.4257792915650727}, {
       0, -0.8763066800438636, -0.4817536741017153}, {
       0, -0.8443279255020151, -0.5358267949789967}, {
       0, -0.8090169943749475, -0.5877852522924731}, {
       0, -0.7705132427757893, -0.6374239897486896}, {
       0, -0.7289686274214116, -0.6845471059286886}, {
       0, -0.6845471059286886, -0.7289686274214116}, {
       0, -0.6374239897486896, -0.7705132427757893}, {
       0, -0.5877852522924731, -0.8090169943749475}, {
       0, -0.5358267949789967, -0.8443279255020151}, {
       0, -0.4817536741017153, -0.8763066800438636}, {
       0, -0.4257792915650727, -0.9048270524660195}, {
       0, -0.3681245526846779, -0.9297764858882515}, {
       0, -0.30901699437494745`, -0.9510565162951535}, {
       0, -0.2486898871648548, -0.9685831611286311}, {
       0, -0.1873813145857246, -0.9822872507286887}, {
       0, -0.12533323356430426`, -0.9921147013144779}, {
       0, -0.06279051952931337, -0.9980267284282716}, {0, 0, -1}, {
       0, 0.06279051952931337, -0.9980267284282716}, {
       0, 0.12533323356430426`, -0.9921147013144779}, {
       0, 0.1873813145857246, -0.9822872507286887}, {
       0, 0.2486898871648548, -0.9685831611286311}, {
       0, 0.30901699437494745`, -0.9510565162951535}, {
       0, 0.3681245526846779, -0.9297764858882515}, {
       0, 0.4257792915650727, -0.9048270524660195}, {
       0, 0.4817536741017153, -0.8763066800438636}, {
       0, 0.5358267949789967, -0.8443279255020151}, {
       0, 0.5877852522924731, -0.8090169943749475}, {
       0, 0.6374239897486896, -0.7705132427757893}, {
       0, 0.6845471059286886, -0.7289686274214116}, {
       0, 0.7289686274214116, -0.6845471059286886}, {
       0, 0.7705132427757893, -0.6374239897486896}, {
       0, 0.8090169943749475, -0.5877852522924731}, {
       0, 0.8443279255020151, -0.5358267949789967}, {
       0, 0.8763066800438636, -0.4817536741017153}, {
       0, 0.9048270524660195, -0.4257792915650727}, {
       0, 0.9297764858882515, -0.3681245526846779}, {
       0, 0.9510565162951535, -0.30901699437494745`}, {
       0, 0.9685831611286311, -0.2486898871648548}, {
       0, 0.9822872507286887, -0.1873813145857246}, {
       0, 0.9921147013144779, -0.12533323356430426`}, {
       0, 0.9980267284282716, -0.06279051952931337}, {0, 1, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {
       Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {
       Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {
       Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {
       Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {0, 1, 
       0}, {-Sin[Rational[1, 50] Pi], Cos[Rational[1, 50] Pi], 0}, {-
        Sin[Rational[1, 25] Pi], Cos[Rational[1, 25] Pi], 0}, {-
        Sin[Rational[3, 50] Pi], Cos[Rational[3, 50] Pi], 0}, {-
        Sin[Rational[2, 25] Pi], Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Sin[Rational[3, 25] Pi], Cos[Rational[3, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[9, 50] Pi], Cos[Rational[9, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {-
        Sin[Rational[11, 50] Pi], Cos[Rational[11, 50] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], Cos[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], Sin[Rational[6, 25] Pi], 0}, {-
        Cos[Rational[11, 50] Pi], Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), (Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[9, 50] Pi], Sin[Rational[9, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[3, 25] Pi], Sin[Rational[3, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {-
        Cos[Rational[2, 25] Pi], Sin[Rational[2, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[1, 50] Pi], Sin[Rational[1, 50] Pi], 0}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {-
        Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {-
        Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {-
        Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 
        0}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {-
        Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 0}, {-
        Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {-
        Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {-
        Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Rational[1, 4] (-1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {-
        Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {-
        Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {-
        Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 
        0}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {-
        Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 0}, {-
        Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {-
        Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {-
        Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Rational[1, 4] (1 - 5^
         Rational[1, 2]), -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0}, {-Sin[Rational[2, 25] Pi], -
        Cos[Rational[2, 25] Pi], 0}, {-Sin[Rational[3, 50] Pi], -
        Cos[Rational[3, 50] Pi], 0}, {-Sin[Rational[1, 25] Pi], -
        Cos[Rational[1, 25] Pi], 0}, {-Sin[Rational[1, 50] Pi], -
        Cos[Rational[1, 50] Pi], 0}, {0, -1, 0}, {
       Sin[Rational[1, 50] Pi], -Cos[Rational[1, 50] Pi], 0}, {
       Sin[Rational[1, 25] Pi], -Cos[Rational[1, 25] Pi], 0}, {
       Sin[Rational[3, 50] Pi], -Cos[Rational[3, 50] Pi], 0}, {
       Sin[Rational[2, 25] Pi], -Cos[Rational[2, 25] Pi], 0}, {
       Rational[1, 4] (-1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Sin[Rational[3, 25] Pi], -Cos[Rational[3, 25] Pi], 0}, {
       Sin[Rational[7, 50] Pi], -Cos[Rational[7, 50] Pi], 0}, {
       Sin[Rational[4, 25] Pi], -Cos[Rational[4, 25] Pi], 0}, {
       Sin[Rational[9, 50] Pi], -Cos[Rational[9, 50] Pi], 
        0}, {(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {
       Sin[Rational[11, 50] Pi], -Cos[Rational[11, 50] Pi], 0}, {
       Sin[Rational[6, 25] Pi], -Cos[Rational[6, 25] Pi], 0}, {
       Cos[Rational[6, 25] Pi], -Sin[Rational[6, 25] Pi], 0}, {
       Cos[Rational[11, 50] Pi], -Sin[Rational[11, 50] Pi], 0}, {
       Rational[1, 4] (1 + 
         5^Rational[1, 2]), -(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0}, {
       Cos[Rational[9, 50] Pi], -Sin[Rational[9, 50] Pi], 0}, {
       Cos[Rational[4, 25] Pi], -Sin[Rational[4, 25] Pi], 0}, {
       Cos[Rational[7, 50] Pi], -Sin[Rational[7, 50] Pi], 0}, {
       Cos[Rational[3, 25] Pi], -Sin[Rational[3, 25] Pi], 
        0}, {(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {
       Cos[Rational[2, 25] Pi], -Sin[Rational[2, 25] Pi], 0}, {
       Cos[Rational[3, 50] Pi], -Sin[Rational[3, 50] Pi], 0}, {
       Cos[Rational[1, 25] Pi], -Sin[Rational[1, 25] Pi], 0}, {
       Cos[Rational[1, 50] Pi], -Sin[Rational[1, 50] Pi], 0}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0.06279051952931337, 0}, {
       0.9921147013144779, 0.12533323356430426`, 0}, {
       0.9822872507286887, 0.1873813145857246, 0}, {
       0.9685831611286311, 0.2486898871648548, 0}, {
       0.9510565162951535, 0.30901699437494745`, 0}, {
       0.9297764858882515, 0.3681245526846779, 0}, {
       0.9048270524660195, 0.4257792915650727, 0}, {
       0.8763066800438636, 0.4817536741017153, 0}, {
       0.8443279255020151, 0.5358267949789967, 0}, {
       0.8090169943749475, 0.5877852522924731, 0}, {
       0.7705132427757893, 0.6374239897486896, 0}, {
       0.7289686274214116, 0.6845471059286886, 0}, {
       0.6845471059286886, 0.7289686274214116, 0}, {
       0.6374239897486896, 0.7705132427757893, 0}, {
       0.5877852522924731, 0.8090169943749475, 0}, {
       0.5358267949789967, 0.8443279255020151, 0}, {
       0.4817536741017153, 0.8763066800438636, 0}, {
       0.4257792915650727, 0.9048270524660195, 0}, {
       0.3681245526846779, 0.9297764858882515, 0}, {
       0.30901699437494745`, 0.9510565162951535, 0}, {
       0.2486898871648548, 0.9685831611286311, 0}, {
       0.1873813145857246, 0.9822872507286887, 0}, {
       0.12533323356430426`, 0.9921147013144779, 0}, {
       0.06279051952931337, 0.9980267284282716, 0}, {0, 1, 
       0}, {-0.06279051952931337, 0.9980267284282716, 
        0}, {-0.12533323356430426`, 0.9921147013144779, 
        0}, {-0.1873813145857246, 0.9822872507286887, 
        0}, {-0.2486898871648548, 0.9685831611286311, 
        0}, {-0.30901699437494745`, 0.9510565162951535, 
        0}, {-0.3681245526846779, 0.9297764858882515, 
        0}, {-0.4257792915650727, 0.9048270524660195, 
        0}, {-0.4817536741017153, 0.8763066800438636, 
        0}, {-0.5358267949789967, 0.8443279255020151, 
        0}, {-0.5877852522924731, 0.8090169943749475, 
        0}, {-0.6374239897486896, 0.7705132427757893, 
        0}, {-0.6845471059286886, 0.7289686274214116, 
        0}, {-0.7289686274214116, 0.6845471059286886, 
        0}, {-0.7705132427757893, 0.6374239897486896, 
        0}, {-0.8090169943749475, 0.5877852522924731, 
        0}, {-0.8443279255020151, 0.5358267949789967, 
        0}, {-0.8763066800438636, 0.4817536741017153, 
        0}, {-0.9048270524660195, 0.4257792915650727, 
        0}, {-0.9297764858882515, 0.3681245526846779, 
        0}, {-0.9510565162951535, 0.30901699437494745`, 
        0}, {-0.9685831611286311, 0.2486898871648548, 
        0}, {-0.9822872507286887, 0.1873813145857246, 
        0}, {-0.9921147013144779, 0.12533323356430426`, 
        0}, {-0.9980267284282716, 0.06279051952931337, 0}, {-1, 0, 
       0}, {-0.9980267284282716, -0.06279051952931337, 
        0}, {-0.9921147013144779, -0.12533323356430426`, 
        0}, {-0.9822872507286887, -0.1873813145857246, 
        0}, {-0.9685831611286311, -0.2486898871648548, 
        0}, {-0.9510565162951535, -0.30901699437494745`, 
        0}, {-0.9297764858882515, -0.3681245526846779, 
        0}, {-0.9048270524660195, -0.4257792915650727, 
        0}, {-0.8763066800438636, -0.4817536741017153, 
        0}, {-0.8443279255020151, -0.5358267949789967, 
        0}, {-0.8090169943749475, -0.5877852522924731, 
        0}, {-0.7705132427757893, -0.6374239897486896, 
        0}, {-0.7289686274214116, -0.6845471059286886, 
        0}, {-0.6845471059286886, -0.7289686274214116, 
        0}, {-0.6374239897486896, -0.7705132427757893, 
        0}, {-0.5877852522924731, -0.8090169943749475, 
        0}, {-0.5358267949789967, -0.8443279255020151, 
        0}, {-0.4817536741017153, -0.8763066800438636, 
        0}, {-0.4257792915650727, -0.9048270524660195, 
        0}, {-0.3681245526846779, -0.9297764858882515, 
        0}, {-0.30901699437494745`, -0.9510565162951535, 
        0}, {-0.2486898871648548, -0.9685831611286311, 
        0}, {-0.1873813145857246, -0.9822872507286887, 
        0}, {-0.12533323356430426`, -0.9921147013144779, 
        0}, {-0.06279051952931337, -0.9980267284282716, 0}, {0, -1, 0}, {
       0.06279051952931337, -0.9980267284282716, 0}, {
       0.12533323356430426`, -0.9921147013144779, 0}, {
       0.1873813145857246, -0.9822872507286887, 0}, {
       0.2486898871648548, -0.9685831611286311, 0}, {
       0.30901699437494745`, -0.9510565162951535, 0}, {
       0.3681245526846779, -0.9297764858882515, 0}, {
       0.4257792915650727, -0.9048270524660195, 0}, {
       0.4817536741017153, -0.8763066800438636, 0}, {
       0.5358267949789967, -0.8443279255020151, 0}, {
       0.5877852522924731, -0.8090169943749475, 0}, {
       0.6374239897486896, -0.7705132427757893, 0}, {
       0.6845471059286886, -0.7289686274214116, 0}, {
       0.7289686274214116, -0.6845471059286886, 0}, {
       0.7705132427757893, -0.6374239897486896, 0}, {
       0.8090169943749475, -0.5877852522924731, 0}, {
       0.8443279255020151, -0.5358267949789967, 0}, {
       0.8763066800438636, -0.4817536741017153, 0}, {
       0.9048270524660195, -0.4257792915650727, 0}, {
       0.9297764858882515, -0.3681245526846779, 0}, {
       0.9510565162951535, -0.30901699437494745`, 0}, {
       0.9685831611286311, -0.2486898871648548, 0}, {
       0.9822872507286887, -0.1873813145857246, 0}, {
       0.9921147013144779, -0.12533323356430426`, 0}, {
       0.9980267284282716, -0.06279051952931337, 0}, {1, 0, 0}}]], 
    Polygon3DBox[
     NCache[{{1, 0, 0}, {
       Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[2, 25] Pi], 0, Sin[
        Rational[2, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 + 5^Rational[1, 2])}, {
       Cos[Rational[3, 25] Pi], 0, Sin[Rational[3, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[9, 50] Pi], 0, Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {
       Sin[Rational[11, 50] Pi], 0, Cos[
        Rational[11, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 + 5^Rational[1, 2])}, {
       Sin[Rational[9, 50] Pi], 0, Cos[Rational[9, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[3, 25] Pi], 0, Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {
       Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {0, 0, 
       1}, {-Sin[Rational[1, 50] Pi], 0, Cos[Rational[1, 50] Pi]}, {-
        Sin[Rational[1, 25] Pi], 0, Cos[Rational[1, 25] Pi]}, {-
        Sin[Rational[3, 50] Pi], 0, Cos[Rational[3, 50] Pi]}, {-
        Sin[Rational[2, 25] Pi], 0, Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Sin[Rational[3, 25] Pi], 0, Cos[
        Rational[3, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, Cos[
        Rational[7, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, Cos[
        Rational[4, 25] Pi]}, {-Sin[Rational[9, 50] Pi], 0, Cos[
        Rational[9, 50] 
         Pi]}, {-(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (1 + 5^Rational[1, 2])}, {-
        Sin[Rational[11, 50] Pi], 0, Cos[Rational[11, 50] Pi]}, {-
        Sin[Rational[6, 25] Pi], 0, Cos[Rational[6, 25] Pi]}, {-
        Cos[Rational[6, 25] Pi], 0, Sin[Rational[6, 25] Pi]}, {-
        Cos[Rational[11, 50] Pi], 0, Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, (Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
        Rational[1, 2]}, {-Cos[Rational[9, 50] Pi], 0, Sin[
        Rational[9, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, Sin[
        Rational[4, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, Sin[
        Rational[7, 50] Pi]}, {-Cos[Rational[3, 25] Pi], 0, Sin[
        Rational[3, 25] 
         Pi]}, {-(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2], 0, Rational[1, 4] (-1 + 5^Rational[1, 2])}, {-
        Cos[Rational[2, 25] Pi], 0, Sin[Rational[2, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[1, 50] Pi], 0, Sin[Rational[1, 50] Pi]}, {-1, 0, 
       0}, {-Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {-
        Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {-
        Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {-
        Cos[Rational[2, 25] Pi], 0, -
        Sin[Rational[2, 25] Pi]}, {-(Rational[5, 8] + 
          Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {-Cos[Rational[3, 25] Pi], 
        0, -Sin[Rational[3, 25] Pi]}, {-Cos[Rational[7, 50] Pi], 0, -
        Sin[Rational[7, 50] Pi]}, {-Cos[Rational[4, 25] Pi], 0, -
        Sin[Rational[4, 25] Pi]}, {-Cos[Rational[9, 50] Pi], 0, -
        Sin[Rational[9, 50] Pi]}, {
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Cos[Rational[11, 50] Pi], 0, -
        Sin[Rational[11, 50] Pi]}, {-Cos[Rational[6, 25] Pi], 0, -
        Sin[Rational[6, 25] Pi]}, {-Sin[Rational[6, 25] Pi], 0, -
        Cos[Rational[6, 25] Pi]}, {-Sin[Rational[11, 50] Pi], 0, -
        Cos[Rational[11, 50] Pi]}, {-(Rational[5, 8] + 
          Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {-Sin[Rational[9, 50] Pi], 
        0, -Cos[Rational[9, 50] Pi]}, {-Sin[Rational[4, 25] Pi], 0, -
        Cos[Rational[4, 25] Pi]}, {-Sin[Rational[7, 50] Pi], 0, -
        Cos[Rational[7, 50] Pi]}, {-Sin[Rational[3, 25] Pi], 0, -
        Cos[Rational[3, 25] Pi]}, {
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {-Sin[Rational[2, 25] Pi], 0, -
        Cos[Rational[2, 25] Pi]}, {-Sin[Rational[3, 50] Pi], 0, -
        Cos[Rational[3, 50] Pi]}, {-Sin[Rational[1, 25] Pi], 0, -
        Cos[Rational[1, 25] Pi]}, {-Sin[Rational[1, 50] Pi], 0, -
        Cos[Rational[1, 50] Pi]}, {0, 0, -1}, {
       Sin[Rational[1, 50] Pi], 0, -Cos[Rational[1, 50] Pi]}, {
       Sin[Rational[1, 25] Pi], 0, -Cos[Rational[1, 25] Pi]}, {
       Sin[Rational[3, 50] Pi], 0, -Cos[Rational[3, 50] Pi]}, {
       Sin[Rational[2, 25] Pi], 0, -Cos[Rational[2, 25] Pi]}, {
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Sin[Rational[3, 25] Pi], 0, -Cos[Rational[3, 25] Pi]}, {
       Sin[Rational[7, 50] Pi], 0, -Cos[Rational[7, 50] Pi]}, {
       Sin[Rational[4, 25] Pi], 0, -Cos[Rational[4, 25] Pi]}, {
       Sin[Rational[9, 50] Pi], 0, -
        Cos[Rational[9, 50] Pi]}, {(Rational[5, 8] + 
         Rational[-1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (-1 - 5^Rational[1, 2])}, {
       Sin[Rational[11, 50] Pi], 0, -Cos[Rational[11, 50] Pi]}, {
       Sin[Rational[6, 25] Pi], 0, -Cos[Rational[6, 25] Pi]}, {
       Cos[Rational[6, 25] Pi], 0, -Sin[Rational[6, 25] Pi]}, {
       Cos[Rational[11, 50] Pi], 0, -Sin[Rational[11, 50] Pi]}, {
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        0, -(Rational[5, 8] + Rational[-1, 8] 5^Rational[1, 2])^
         Rational[1, 2]}, {
       Cos[Rational[9, 50] Pi], 0, -Sin[Rational[9, 50] Pi]}, {
       Cos[Rational[4, 25] Pi], 0, -Sin[Rational[4, 25] Pi]}, {
       Cos[Rational[7, 50] Pi], 0, -Sin[Rational[7, 50] Pi]}, {
       Cos[Rational[3, 25] Pi], 0, -
        Sin[Rational[3, 25] Pi]}, {(Rational[5, 8] + 
         Rational[1, 8] 5^Rational[1, 2])^Rational[1, 2], 0, 
        Rational[1, 4] (1 - 5^Rational[1, 2])}, {
       Cos[Rational[2, 25] Pi], 0, -Sin[Rational[2, 25] Pi]}, {
       Cos[Rational[3, 50] Pi], 0, -Sin[Rational[3, 50] Pi]}, {
       Cos[Rational[1, 25] Pi], 0, -Sin[Rational[1, 25] Pi]}, {
       Cos[Rational[1, 50] Pi], 0, -Sin[Rational[1, 50] Pi]}, {1, 0, 0}}, {{1,
        0, 0}, {0.9980267284282716, 0, 0.06279051952931337}, {
       0.9921147013144779, 0, 0.12533323356430426`}, {
       0.9822872507286887, 0, 0.1873813145857246}, {
       0.9685831611286311, 0, 0.2486898871648548}, {
       0.9510565162951535, 0, 0.30901699437494745`}, {
       0.9297764858882515, 0, 0.3681245526846779}, {
       0.9048270524660195, 0, 0.4257792915650727}, {
       0.8763066800438636, 0, 0.4817536741017153}, {
       0.8443279255020151, 0, 0.5358267949789967}, {
       0.8090169943749475, 0, 0.5877852522924731}, {
       0.7705132427757893, 0, 0.6374239897486896}, {
       0.7289686274214116, 0, 0.6845471059286886}, {
       0.6845471059286886, 0, 0.7289686274214116}, {
       0.6374239897486896, 0, 0.7705132427757893}, {
       0.5877852522924731, 0, 0.8090169943749475}, {
       0.5358267949789967, 0, 0.8443279255020151}, {
       0.4817536741017153, 0, 0.8763066800438636}, {
       0.4257792915650727, 0, 0.9048270524660195}, {
       0.3681245526846779, 0, 0.9297764858882515}, {
       0.30901699437494745`, 0, 0.9510565162951535}, {
       0.2486898871648548, 0, 0.9685831611286311}, {
       0.1873813145857246, 0, 0.9822872507286887}, {
       0.12533323356430426`, 0, 0.9921147013144779}, {
       0.06279051952931337, 0, 0.9980267284282716}, {0, 0, 
       1}, {-0.06279051952931337, 0, 
        0.9980267284282716}, {-0.12533323356430426`, 0, 
        0.9921147013144779}, {-0.1873813145857246, 0, 
        0.9822872507286887}, {-0.2486898871648548, 0, 
        0.9685831611286311}, {-0.30901699437494745`, 0, 
        0.9510565162951535}, {-0.3681245526846779, 0, 
        0.9297764858882515}, {-0.4257792915650727, 0, 
        0.9048270524660195}, {-0.4817536741017153, 0, 
        0.8763066800438636}, {-0.5358267949789967, 0, 
        0.8443279255020151}, {-0.5877852522924731, 0, 
        0.8090169943749475}, {-0.6374239897486896, 0, 
        0.7705132427757893}, {-0.6845471059286886, 0, 
        0.7289686274214116}, {-0.7289686274214116, 0, 
        0.6845471059286886}, {-0.7705132427757893, 0, 
        0.6374239897486896}, {-0.8090169943749475, 0, 
        0.5877852522924731}, {-0.8443279255020151, 0, 
        0.5358267949789967}, {-0.8763066800438636, 0, 
        0.4817536741017153}, {-0.9048270524660195, 0, 
        0.4257792915650727}, {-0.9297764858882515, 0, 
        0.3681245526846779}, {-0.9510565162951535, 0, 
        0.30901699437494745`}, {-0.9685831611286311, 0, 
        0.2486898871648548}, {-0.9822872507286887, 0, 
        0.1873813145857246}, {-0.9921147013144779, 0, 
        0.12533323356430426`}, {-0.9980267284282716, 0, 
        0.06279051952931337}, {-1, 0, 
       0}, {-0.9980267284282716, 
        0, -0.06279051952931337}, {-0.9921147013144779, 
        0, -0.12533323356430426`}, {-0.9822872507286887, 
        0, -0.1873813145857246}, {-0.9685831611286311, 
        0, -0.2486898871648548}, {-0.9510565162951535, 
        0, -0.30901699437494745`}, {-0.9297764858882515, 
        0, -0.3681245526846779}, {-0.9048270524660195, 
        0, -0.4257792915650727}, {-0.8763066800438636, 
        0, -0.4817536741017153}, {-0.8443279255020151, 
        0, -0.5358267949789967}, {-0.8090169943749475, 
        0, -0.5877852522924731}, {-0.7705132427757893, 
        0, -0.6374239897486896}, {-0.7289686274214116, 
        0, -0.6845471059286886}, {-0.6845471059286886, 
        0, -0.7289686274214116}, {-0.6374239897486896, 
        0, -0.7705132427757893}, {-0.5877852522924731, 
        0, -0.8090169943749475}, {-0.5358267949789967, 
        0, -0.8443279255020151}, {-0.4817536741017153, 
        0, -0.8763066800438636}, {-0.4257792915650727, 
        0, -0.9048270524660195}, {-0.3681245526846779, 
        0, -0.9297764858882515}, {-0.30901699437494745`, 
        0, -0.9510565162951535}, {-0.2486898871648548, 
        0, -0.9685831611286311}, {-0.1873813145857246, 
        0, -0.9822872507286887}, {-0.12533323356430426`, 
        0, -0.9921147013144779}, {-0.06279051952931337, 
        0, -0.9980267284282716}, {0, 0, -1}, {
       0.06279051952931337, 0, -0.9980267284282716}, {
       0.12533323356430426`, 0, -0.9921147013144779}, {
       0.1873813145857246, 0, -0.9822872507286887}, {
       0.2486898871648548, 0, -0.9685831611286311}, {
       0.30901699437494745`, 0, -0.9510565162951535}, {
       0.3681245526846779, 0, -0.9297764858882515}, {
       0.4257792915650727, 0, -0.9048270524660195}, {
       0.4817536741017153, 0, -0.8763066800438636}, {
       0.5358267949789967, 0, -0.8443279255020151}, {
       0.5877852522924731, 0, -0.8090169943749475}, {
       0.6374239897486896, 0, -0.7705132427757893}, {
       0.6845471059286886, 0, -0.7289686274214116}, {
       0.7289686274214116, 0, -0.6845471059286886}, {
       0.7705132427757893, 0, -0.6374239897486896}, {
       0.8090169943749475, 0, -0.5877852522924731}, {
       0.8443279255020151, 0, -0.5358267949789967}, {
       0.8763066800438636, 0, -0.4817536741017153}, {
       0.9048270524660195, 0, -0.4257792915650727}, {
       0.9297764858882515, 0, -0.3681245526846779}, {
       0.9510565162951535, 0, -0.30901699437494745`}, {
       0.9685831611286311, 0, -0.2486898871648548}, {
       0.9822872507286887, 0, -0.1873813145857246}, {
       0.9921147013144779, 0, -0.12533323356430426`}, {
       0.9980267284282716, 0, -0.06279051952931337}, {1, 0, 0}}]], 
    SphereBox[{0, 0, 0}, 1], 
    {Opacity[1], Arrow3DBox[TubeBox[{{0, 0, 0}, {1, 0, 0}}]], 
     Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1, 0}}]], 
     Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1}}]], Text3DBox[
      StyleBox["\<\"x\"\>",
       StripOnInput->False,
       FontSize->Large], {1.1, 0, 0}], Text3DBox[
      StyleBox["\<\"y\"\>",
       StripOnInput->False,
       FontSize->Large], {0, 1.1, 0}], Text3DBox[
      StyleBox["\<\"z\"\>",
       StripOnInput->False,
       FontSize->Large], {0, 0, 1.1}]}}, {{}, {}, 
    {RGBColor[0, 0, 1], Thickness[Large], Line3DBox[CompressedData["
1:eJzUWPc/1X/YlkhCGki+RklZ7QitO9GwWjSkpEKyQqIQlSgUsmf2lr3XbRx7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      "]]}}},
  AutomaticImageSize->True,
  Boxed->False,
  ImageSize->{382.2690425390747, 388.8094063647664},
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  ViewPoint->{1.5474371334672619`, -2.7062053753018622`, 1.3160132159875648`},
  
  ViewVertical->{0.11391082451156233`, -0.20074265392134363`, 
   0.9729988237175377}]], "Output",
 CellChangeTimes->{{3.573476762866603*^9, 3.573476820208233*^9}, {
   3.5734768835754547`*^9, 3.57347690927414*^9}, 3.573477297656971*^9, 
   3.573477415969747*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
The trajectory shows the partial inversion by the weak pulse (in the presence \
of the resonance offset and also the relaxation) followed by precession and \
relaxation back to equilibrium.\
\>", "Text",
 CellChangeTimes->{{3.573477315609024*^9, 3.573477344985433*^9}}]
}, Open  ]]
},
WindowSize->{862, 794},
WindowMargins->{{Automatic, -949}, {Automatic, 33}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3573477287-1274295"->{
  Cell[7528, 226, 369, 6, 60, "Print",
   CellTags->"Info3573477287-1274295"]},
 "Info3573477292-1274295"->{
  Cell[9547, 281, 320, 5, 58, "Print",
   CellTags->"Info3573477292-1274295"]},
 "Info3573477415-1274295"->{
  Cell[17835, 498, 316, 5, 59, "Print",
   CellTags->"Info3573477415-1274295"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3573477287-1274295", 245394, 4341},
 {"Info3573477292-1274295", 245503, 4344},
 {"Info3573477415-1274295", 245612, 4347}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 197, 3, 27, "Input"],
Cell[767, 27, 194, 5, 32, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[998, 37, 158, 3, 27, "Input"],
Cell[1159, 42, 300, 7, 39, "Message"],
Cell[1462, 51, 382, 9, 39, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1881, 65, 219, 3, 34, "Subsection"],
Cell[2103, 70, 246, 5, 26, "Text"],
Cell[2352, 77, 339, 6, 27, "Input"],
Cell[2694, 85, 976, 28, 43, "Input"],
Cell[3673, 115, 199, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[3897, 123, 289, 6, 43, "Input"],
Cell[4189, 131, 980, 28, 89, "Output"]
}, Open  ]],
Cell[5184, 162, 212, 4, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5433, 171, 282, 3, 34, "Subsection"],
Cell[5718, 176, 232, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[5975, 186, 186, 4, 27, "Input"],
Cell[6164, 192, 898, 17, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7111, 215, 279, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[7415, 222, 110, 2, 27, "Input"],
Cell[7528, 226, 369, 6, 60, "Print",
 CellTags->"Info3573477287-1274295"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7934, 237, 603, 11, 103, "Input"],
Cell[8540, 250, 378, 9, 39, "Message"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8967, 265, 434, 8, 34, "Subsection"],
Cell[CellGroupData[{
Cell[9426, 277, 118, 2, 27, "Input"],
Cell[9547, 281, 320, 5, 58, "Print",
 CellTags->"Info3573477292-1274295"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9904, 291, 264, 5, 27, "Input"],
Cell[10171, 298, 1244, 29, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11464, 333, 477, 8, 34, "Subsection"],
Cell[CellGroupData[{
Cell[11966, 345, 1179, 29, 58, "Input"],
Cell[13148, 376, 581, 18, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13778, 400, 443, 7, 34, "Subsection"],
Cell[14224, 409, 227, 5, 27, "Input"],
Cell[14454, 416, 210, 5, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14701, 426, 506, 8, 34, "Subsection"],
Cell[CellGroupData[{
Cell[15232, 438, 580, 12, 43, "Input"],
Cell[15815, 452, 1261, 23, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17125, 481, 547, 9, 35, "Subsection"],
Cell[CellGroupData[{
Cell[17697, 494, 135, 2, 27, "Input"],
Cell[17835, 498, 316, 5, 59, "Print",
 CellTags->"Info3573477415-1274295"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18188, 508, 1564, 30, 118, "Input"],
Cell[19755, 540, 3263, 75, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23055, 620, 1262, 24, 43, "Input"],
Cell[24320, 646, 76247, 1255, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100604, 1906, 888, 22, 118, "Input"],
Cell[101495, 1930, 143188, 2386, 404, 87910, 1478, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[244698, 4319, 279, 5, 41, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
